@@ -68,7 +68,7 @@ define([
         }
         this.fileExtensions = {
             'csv': 'csv',
-            'excel': 'xls',
+            'excel': 'xlsx',
             'json': 'json',
             'pickle': 'pickle'
         }
