@@ -324,7 +324,7 @@
         
         var viewRect = (liveNotebook ? document.getElementById('site') : document.body).getBoundingClientRect();
         var wrap = $(vpCommon.getVPContainer()).addClass('sidebar-wrapper').resizable('option', 'handles', 'w');
-        wrap.children('.ui-resizable-w').addClass('ui-icon ui-icon-grip-dotted-vertical');
+        // wrap.children('.ui-resizable-w').addClass('ui-icon ui-icon-grip-dotted-vertical');
         wrap.css({ top: liveNotebook ? viewRect.top : "110px", height: '', right: 0 });
         setNotebookWidth(cfg);
     };
@@ -552,6 +552,13 @@
     // 기본설정 불러오기
     readDefaultConfig();
 
+    // Operations on kernel restart
+    events.on('kernel_ready.Kernel', function (evt, info) {
+        console.log('vp operations for kernel ready...');
+        // read vp functions
+        read_kernel_functions();
+    });
+
     return {
         vpInit: vpInit, readConfig: readConfig
     };
